@@ -101,6 +101,8 @@ def st_folium(
 
     # handle the case where you pass in a figure rather than a map
     # this assumes that a map is the first child
+    fig.render()
+
     if not (isinstance(fig, folium.Map) or isinstance(fig, folium.plugins.DualMap)):
         fig = list(fig._children.values())[0]
 
@@ -121,6 +123,9 @@ def st_folium(
     # Get rid of the annoying popup
     leaflet = leaflet.replace("alert(coords);", "")
 
+    if "drawnItems" not in leaflet:
+        leaflet += "\nvar drawnItems = [];"
+
     component_value = _component_func(
         fig=leaflet,
         id=m_id,
